@@ -27,6 +27,7 @@ except ImportError:
 
 import eventlet
 
+from oslo_log import log
 from tempest.lib import exceptions
 
 from neutron_tempest_plugin import config
@@ -37,6 +38,7 @@ SCHEMA_PORT_MAPPING = {
     "https": 443,
 }
 CONF = config.CONF
+LOG = log.getLogger(__name__)
 
 
 class classproperty(object):
@@ -155,6 +157,8 @@ class StatefulConnection:
         self.port = target_port
         self.connection_started = False
         self.test_attempt = 0
+        self.test_timeout = 10
+        self.test_sleep = 1
 
     def __enter__(self):
         return self
@@ -173,13 +177,21 @@ class StatefulConnection:
 
         self.server_ssh.exec_command(
                 'echo "{}" > input.txt'.format(self.test_str))
-        server_exec_method('tail -f input.txt | nc -lp '
+        server_exec_method('tail -f input.txt | sudo nc -lp '
                 '{} &> output.txt &'.format(self.port))
         self.client_ssh.exec_command(
                 'echo "{}" > input.txt'.format(self.test_str))
-        client_exec_method('tail -f input.txt | nc {} {} &>'
+        client_exec_method('tail -f input.txt | sudo nc {} {} &>'
                 'output.txt &'.format(self.ip, self.port))
 
+    def _nc_is_running(self):
+        server = process_is_running(self.server_ssh, 'nc')
+        client = process_is_running(self.client_ssh, 'nc')
+        if client and server:
+            return True
+        else:
+            return False
+
     def _test_connection(self):
         if not self.connection_started:
             self._start_connection()
@@ -188,29 +200,45 @@ class StatefulConnection:
                     'echo "{}" >> input.txt'.format(self.test_str))
             self.client_ssh.exec_command(
                     'echo "{}" >> input.txt & sleep 1'.format(self.test_str))
+        wait_until_true(self._nc_is_running,
+                        timeout=self.test_timeout,
+                        sleep=self.test_sleep)
         try:
+            LOG.info("Checking connectivity between server and client -"
+                    " attempt {}".format(self.test_attempt))
             self.server_ssh.exec_command(
                     'grep {} output.txt'.format(self.test_str))
             self.client_ssh.exec_command(
                     'grep {} output.txt'.format(self.test_str))
             if not self.should_pass:
+                LOG.warning("attempt {} succeed while it should fail".format(
+                    self.test_attempt))
                 return False
             else:
                 if not self.connection_started:
                     self.connection_started = True
+                LOG.info("attempt {} succeed as it expected".format(
+                    self.test_attempt))
                 return True
         except exceptions.SSHExecCommandFailed:
             if self.should_pass:
+                LOG.warning("attempt {} failed while it should pass".format(
+                    self.test_attempt))
                 return False
             else:
+                LOG.info("attempt {} failed as it expected".format(
+                    self.test_attempt))
                 return True
         finally:
             self.test_attempt += 1
 
     def test_connection(self, should_pass=True, timeout=10, sleep_timer=1):
         self.should_pass = should_pass
-        wait_until_true(
-                self._test_connection, timeout=timeout, sleep=sleep_timer)
+        self.test_timeout = timeout
+        self.test_sleep = sleep_timer
+        wait_until_true(self._test_connection,
+                        timeout=self.test_timeout,
+                        sleep=self.test_sleep)
 
     def __exit__(self, type, value, traceback):
         self.server_ssh.exec_command('sudo killall nc || killall nc || '
